[Asterisk-code-review] res: Spelling fixes (asterisk[master])

Friendly Automation asteriskteam at digium.com
Mon Nov 15 16:37:37 CST 2021


Friendly Automation has submitted this change. ( https://gerrit.asterisk.org/c/asterisk/+/17312 )

Change subject: res: Spelling fixes
......................................................................

res: Spelling fixes

Correct typos of the following word families:

identifying
structures
actcount
initializer
attributes
statement
enough
locking
declaration
userevent
provides
unregister
session
execute
searches
verification
suppressed
prepared
passwords
recipients
event
because
brief
unidentified
redundancy
character
the
module
reload
operation
backslashes
accurate
incorrect
collision
initializing
instance
interpreted
buddies
omitted
manually
requires
queries
generator
scheduler
configuration has
owner
resource
performed
masquerade
apparently
routable

ASTERISK-29714

Change-Id: I88485116d2c59b776aa2e1f8b4ce8239a21decda
---
M res/ael/ael.y
M res/ael/pval.c
M res/ari/resource_bridges.c
M res/ari/resource_events.c
M res/parking/res_parking.h
M res/prometheus/pjsip_outbound_registrations.c
M res/res_agi.c
M res/res_ari.c
M res/res_calendar.c
M res/res_calendar_caldav.c
M res/res_calendar_icalendar.c
M res/res_config_curl.c
M res/res_config_ldap.c
M res/res_config_odbc.c
M res/res_config_pgsql.c
M res/res_corosync.c
M res/res_fax_spandsp.c
M res/res_http_post.c
M res/res_musiconhold.c
M res/res_phoneprov.c
M res/res_pjsip.c
M res/res_pjsip/config_global.c
M res/res_pjsip/pjsip_configuration.c
M res/res_pjsip/pjsip_scheduler.c
M res/res_pjsip/pjsip_session.c
M res/res_pjsip_config_wizard.c
M res/res_pjsip_header_funcs.c
M res/res_pjsip_messaging.c
M res/res_pjsip_nat.c
M res/res_pjsip_outbound_authenticator_digest.c
M res/res_pjsip_outbound_registration.c
M res/res_pjsip_pubsub.c
M res/res_pjsip_rfc3326.c
M res/res_pjsip_session.c
M res/res_pktccops.c
M res/res_rtp_asterisk.c
M res/res_smdi.c
M res/res_sorcery_config.c
M res/res_stasis.c
M res/res_stasis_playback.c
M res/res_stir_shaken/curl.c
M res/res_stir_shaken/curl.h
M res/res_xmpp.c
M res/snmp/agent.c
M res/stasis_recording/stored.c
45 files changed, 68 insertions(+), 68 deletions(-)

Approvals:
  Joshua Colp: Looks good to me, but someone else must approve
  George Joseph: Looks good to me, approved
  Friendly Automation: Approved for Submit



diff --git a/res/ael/ael.y b/res/ael/ael.y
index da13c66..e223fd6 100644
--- a/res/ael/ael.y
+++ b/res/ael/ael.y
@@ -464,7 +464,7 @@
 	;
 
 /*
- * Definition of a statememt in our language
+ * Definition of a statement in our language
  */
 statement : LC statements RC {
 		$$ = npval2(PV_STATEMENTBLOCK, &@1, &@3);
diff --git a/res/ael/pval.c b/res/ael/pval.c
index b85e20e..10af159 100644
--- a/res/ael/pval.c
+++ b/res/ael/pval.c
@@ -528,7 +528,7 @@
 		break;
 
 	case PV_FOR:
-		/* fields: item->u1.for_init     == a string containing the initalizer
+		/* fields: item->u1.for_init     == a string containing the initializer
 		           item->u2.for_test     == a string containing the loop test
 		           item->u3.for_inc      == a string containing the loop increment
 
@@ -1470,7 +1470,7 @@
 		break;
 
 	case PV_FOR:
-		/* fields: item->u1.for_init     == a string containing the initalizer
+		/* fields: item->u1.for_init     == a string containing the initializer
 		           item->u2.for_test     == a string containing the loop test
 		           item->u3.for_inc      == a string containing the loop increment
 
@@ -1697,7 +1697,7 @@
 		break;
 
 	case PV_FOR:
-		/* fields: item->u1.for_init     == a string containing the initalizer
+		/* fields: item->u1.for_init     == a string containing the initializer
 		           item->u2.for_test     == a string containing the loop test
 		           item->u3.for_inc      == a string containing the loop increment
 
@@ -2686,7 +2686,7 @@
 		break;
 
 	case PV_FOR:
-		/* fields: item->u1.for_init     == a string containing the initalizer
+		/* fields: item->u1.for_init     == a string containing the initializer
 		           item->u2.for_test     == a string containing the loop test
 		           item->u3.for_inc      == a string containing the loop increment
 
@@ -3214,7 +3214,7 @@
 		break;
 
 	case PV_FOR:
-		/* fields: item->u1.for_init     == a string containing the initalizer
+		/* fields: item->u1.for_init     == a string containing the initializer
 		           item->u2.for_test     == a string containing the loop test
 		           item->u3.for_inc      == a string containing the loop increment
 
@@ -4820,7 +4820,7 @@
 		break;
 
 	case PV_FOR:
-		/* fields: item->u1.for_init     == a string containing the initalizer
+		/* fields: item->u1.for_init     == a string containing the initializer
 		           item->u2.for_test     == a string containing the loop test
 		           item->u3.for_inc      == a string containing the loop increment
 
diff --git a/res/ari/resource_bridges.c b/res/ari/resource_bridges.c
index d03e86f..1d1cc8b 100644
--- a/res/ari/resource_bridges.c
+++ b/res/ari/resource_bridges.c
@@ -346,7 +346,7 @@
  * \param args_playback_id string to use for playback split from
  *        arguments (null valid)
  * \param response ARI response being built
- * \param bridge Bridge the playback is being peformed on
+ * \param bridge Bridge the playback is being performed on
  * \param control Control being used for the playback channel
  * \param json contents of the response to ARI
  * \param playback_url stores playback URL for use with response
@@ -517,7 +517,7 @@
  * \param args_playback_id string to use for playback split from
  *        arguments (null valid)
  * \param response ARI response being built
- * \param bridge Bridge the playback is being peformed on
+ * \param bridge Bridge the playback is being performed on
  * \param found_channel The channel that was found controlling playback
  *
  * \retval PLAY_FOUND_SUCCESS The operation was successful
diff --git a/res/ari/resource_events.c b/res/ari/resource_events.c
index f70de43..951cd33 100644
--- a/res/ari/resource_events.c
+++ b/res/ari/resource_events.c
@@ -86,7 +86,7 @@
 	ast_assert(session != NULL);
 
 	/*
-	 * We need to get the debug flag before lockinf session
+	 * We need to get the debug flag before locking session
 	 * to help prevent a deadlock with the apps_registry container.
 	 */
 	app_debug_enabled = stasis_app_get_debug_by_name(app_name);
@@ -574,7 +574,7 @@
 
 	case STASIS_APP_USER_USEREVENT_INVALID:
 		ast_ari_response_error(response, 400, "Bad Request",
-			"Invalid userevnet data");
+			"Invalid userevent data");
 		break;
 
 	case STASIS_APP_USER_INTERNAL_ERROR:
diff --git a/res/parking/res_parking.h b/res/parking/res_parking.h
index a1a5f49..cd0b79f 100644
--- a/res/parking/res_parking.h
+++ b/res/parking/res_parking.h
@@ -431,7 +431,7 @@
  *        to necessary parking information when joining, and applying various bridge roles to the
  *        channel.
  *
- * \param parkee The channel being preparred for parking
+ * \param parkee The channel being prepared for parking
  * \param parker The channel initiating the park; may be the parkee as well. May be NULL.
  * \param app_data arguments supplied to the Park application. May be NULL.
  * \param silence_announcements optional pointer to an integer where we want to store the silence option flag
diff --git a/res/prometheus/pjsip_outbound_registrations.c b/res/prometheus/pjsip_outbound_registrations.c
index add3648..c036772 100644
--- a/res/prometheus/pjsip_outbound_registrations.c
+++ b/res/prometheus/pjsip_outbound_registrations.c
@@ -47,7 +47,7 @@
  *
  * \details We keep a wrapper around the metric so we can easily
  * update the value when the state of the registration changes, as
- * well as remove and unregsiter the metric when someone destroys
+ * well as remove and unregister the metric when someone destroys
  * or reloads the registration
  */
 struct prometheus_metric_wrapper {
diff --git a/res/res_agi.c b/res/res_agi.c
index b10e4ab..631c9b8 100644
--- a/res/res_agi.c
+++ b/res/res_agi.c
@@ -3010,7 +3010,7 @@
 			switch(f->frametype) {
 			case AST_FRAME_DTMF:
 				if (strchr(argv[4], f->subclass.integer)) {
-					/* This is an interrupting chracter, so rewind to chop off any small
+					/* This is an interrupting character, so rewind to chop off any small
 					   amount of DTMF that may have been recorded
 					*/
 					ast_stream_rewind(fs, 200);
diff --git a/res/res_ari.c b/res/res_ari.c
index 682d3e9..8289420 100644
--- a/res/res_ari.c
+++ b/res/res_ari.c
@@ -43,7 +43,7 @@
  * The structure of the generated code is:
  *
  *  - res/ari/resource_{resource}.h
- *    - For each operation in the resouce, a generated argument structure
+ *    - For each operation in the resource, a generated argument structure
  *      (holding the parsed arguments from the request) and function
  *      declarations (to implement in res/ari/resource_{resource}.c)
  *  - res_ari_{resource}.c
diff --git a/res/res_calendar.c b/res/res_calendar.c
index 95f3e20..ba00796 100644
--- a/res/res_calendar.c
+++ b/res/res_calendar.c
@@ -83,7 +83,7 @@
 					<enum name="summary"><para>The VEVENT SUMMARY property or Exchange event 'subject'</para></enum>
 					<enum name="description"><para>The text description of the event</para></enum>
 					<enum name="organizer"><para>The organizer of the event</para></enum>
-					<enum name="location"><para>The location of the eventt</para></enum>
+					<enum name="location"><para>The location of the event</para></enum>
 					<enum name="categories"><para>The categories of the event</para></enum>
 					<enum name="priority"><para>The priority of the event</para></enum>
 					<enum name="calendar"><para>The name of the calendar associated with the event</para></enum>
diff --git a/res/res_calendar_caldav.c b/res/res_calendar_caldav.c
index 425a1e3..9bdde0e 100644
--- a/res/res_calendar_caldav.c
+++ b/res/res_calendar_caldav.c
@@ -339,7 +339,7 @@
 }
 
 /* span->start & span->end may be dates or floating times which have no timezone,
- * which would mean that they should apply to the local timezone for all recepients.
+ * which would mean that they should apply to the local timezone for all recipients.
  * For example, if a meeting was set for 1PM-2PM floating time, people in different time
  * zones would not be scheduled at the same local times.  Dates are often treated as
  * floating times, so all day events will need to be converted--so we can trust the
@@ -400,7 +400,7 @@
 	if ((prop = icalcomponent_get_first_property(comp, ICAL_UID_PROPERTY))) {
 		ast_string_field_set(event, uid, icalproperty_get_value_as_string(prop));
 	} else {
-		ast_log(LOG_WARNING, "No UID found, but one is required. Generating, but updates may not be acurate\n");
+		ast_log(LOG_WARNING, "No UID found, but one is required. Generating, but updates may not be accurate\n");
 		if (!ast_strlen_zero(event->summary)) {
 			ast_string_field_set(event, uid, event->summary);
 		} else {
diff --git a/res/res_calendar_icalendar.c b/res/res_calendar_icalendar.c
index debb55c..999cf0e 100644
--- a/res/res_calendar_icalendar.c
+++ b/res/res_calendar_icalendar.c
@@ -198,7 +198,7 @@
 	struct icaltriggertype trigger;
 
 	if (!(pvt && pvt->owner)) {
-		ast_log(LOG_ERROR, "Require a private structure with an ownenr\n");
+		ast_log(LOG_ERROR, "Require a private structure with an owner\n");
 		return;
 	}
 
@@ -241,7 +241,7 @@
 	if ((prop = icalcomponent_get_first_property(comp, ICAL_UID_PROPERTY))) {
 		ast_string_field_set(event, uid, icalproperty_get_value_as_string(prop));
 	} else {
-		ast_log(LOG_WARNING, "No UID found, but one is required. Generating, but updates may not be acurate\n");
+		ast_log(LOG_WARNING, "No UID found, but one is required. Generating, but updates may not be accurate\n");
 		if (!ast_strlen_zero(event->summary)) {
 			ast_string_field_set(event, uid, event->summary);
 		} else {
diff --git a/res/res_config_curl.c b/res/res_config_curl.c
index 5fd38d5..a124958 100644
--- a/res/res_config_curl.c
+++ b/res/res_config_curl.c
@@ -121,7 +121,7 @@
 }
 
 /*!
- * \brief Excute an Select query and return ast_config list
+ * \brief Execute an Select query and return ast_config list
  * \param url
  * \param unused
  * \param fields list containing one or more field/operator/value set.
diff --git a/res/res_config_ldap.c b/res/res_config_ldap.c
index accd633..3d02c21 100644
--- a/res/res_config_ldap.c
+++ b/res/res_config_ldap.c
@@ -405,7 +405,7 @@
 	int delim_tot_count = 0;
 	int delim_count = 0;
 
-	/* \breif First find the total count
+	/* \brief First find the total count
 	 */
 	ldap_entry = ldap_first_entry(ldapConn, ldap_result_msg);
 
@@ -1758,7 +1758,7 @@
 	return 0;
 }
 
-/*! \breif Relod Module
+/*! \brief Reload Module
  */
 static int reload(void)
 {
diff --git a/res/res_config_odbc.c b/res/res_config_odbc.c
index fd0078f..0d4f767 100644
--- a/res/res_config_odbc.c
+++ b/res/res_config_odbc.c
@@ -155,7 +155,7 @@
 }
 
 /*!
- * \brief Excute an SQL query and return ast_variable list
+ * \brief Execute an SQL query and return ast_variable list
  * \param database
  * \param table
  * \param ap list containing one or more field/operator/value set.
@@ -326,7 +326,7 @@
 }
 
 /*!
- * \brief Excute an Select query and return ast_config list
+ * \brief Execute an Select query and return ast_config list
  * \param database
  * \param table
  * \param ap list containing one or more field/operator/value set.
@@ -499,7 +499,7 @@
 }
 
 /*!
- * \brief Excute an UPDATE query
+ * \brief Execute an UPDATE query
  * \param database
  * \param table
  * \param keyfield where clause field
@@ -726,7 +726,7 @@
 }
 
 /*!
- * \brief Excute an INSERT query
+ * \brief Execute an INSERT query
  * \param database
  * \param table
  * \param ap list containing one or more field/value set(s)
@@ -807,7 +807,7 @@
 }
 
 /*!
- * \brief Excute an DELETE query
+ * \brief Execute an DELETE query
  * \param database
  * \param table
  * \param keyfield where clause field
diff --git a/res/res_config_pgsql.c b/res/res_config_pgsql.c
index 6f49f8e..81c165b 100644
--- a/res/res_config_pgsql.c
+++ b/res/res_config_pgsql.c
@@ -126,7 +126,7 @@
 	ast_free(table);
 }
 
-/*! \brief Helper function for pgsql_exec.  For running querys, use pgsql_exec()
+/*! \brief Helper function for pgsql_exec.  For running queries, use pgsql_exec()
  *
  *  Connect if not currently connected.  Run the given query.
  *
diff --git a/res/res_corosync.c b/res/res_corosync.c
index e5448b9..409f64e 100644
--- a/res/res_corosync.c
+++ b/res/res_corosync.c
@@ -808,7 +808,7 @@
 		ast_rwlock_unlock(&init_cpg_lock);
 		ast_debug(5, "dispatch_thread_handler unlock\n");
 	} else {
-		ast_log(LOG_ERROR, "Failed to get fd: initiliazing CPG.  This module is now broken.\n");
+		ast_log(LOG_ERROR, "Failed to get fd: initializing CPG.  This module is now broken.\n");
 		return NULL;
 	}
 	send_cluster_notify();
diff --git a/res/res_fax_spandsp.c b/res/res_fax_spandsp.c
index 045dbc7..030dfc0 100644
--- a/res/res_fax_spandsp.c
+++ b/res/res_fax_spandsp.c
@@ -890,7 +890,7 @@
 /*! \brief process a frame from the bridge
  * \param s fax session
  * \param f frame to process
- * \return 1 on sucess 0 on incorect packet*/
+ * \return 1 on sucess 0 on incorrect packet*/
 static int spandsp_fax_gateway_process(struct ast_fax_session *s, const struct ast_frame *f)
 {
 	struct spandsp_pvt *p = s->tech_pvt;
diff --git a/res/res_http_post.c b/res/res_http_post.c
index a77ef0d..069c102 100644
--- a/res/res_http_post.c
+++ b/res/res_http_post.c
@@ -263,7 +263,7 @@
 				marker += x;  /* Index beyond the filename marker */
 				path_start = &buf[marker];
 				for (path_end = path_start, x = 0; x < char_in_buf-marker; x++, path_end++) {
-					if ('\\' == *path_end) {	/* convert backslashses to forward slashes */
+					if ('\\' == *path_end) {	/* convert backslashes to forward slashes */
 						*path_end = '/';
 					}
 					if ('\"' == *path_end) {	/* If at the end of the file name spec */
diff --git a/res/res_musiconhold.c b/res/res_musiconhold.c
index 9811ea7..9844de0 100644
--- a/res/res_musiconhold.c
+++ b/res/res_musiconhold.c
@@ -90,7 +90,7 @@
 			<para>Plays hold music specified by class. If omitted, the default music
 			source for the channel will be used. Change the default class with
 			Set(CHANNEL(musicclass)=...). If duration is given, hold music will be played
-			specified number of seconds. If duration is ommited, music plays indefinitely.
+			specified number of seconds. If duration is omitted, music plays indefinitely.
 			Returns <literal>0</literal> when done, <literal>-1</literal> on hangup.</para>
 			<para>This application does not automatically answer and should be preceeded by
 			an application such as Answer() or Progress().</para>
@@ -1741,7 +1741,7 @@
 					return -1;
 				}
 			} else {
-				/* We don't register RT moh class, so let's init it manualy */
+				/* We don't register RT moh class, so let's init it manually */
 
 				time(&mohclass->start);
 				mohclass->start -= respawn_time;
diff --git a/res/res_phoneprov.c b/res/res_phoneprov.c
index ad74ae0..b0906c9 100644
--- a/res/res_phoneprov.c
+++ b/res/res_phoneprov.c
@@ -1074,7 +1074,7 @@
 	AST_STANDARD_APP_ARGS(args, data);
 
 	if (ast_strlen_zero(args.mac) || ast_strlen_zero(args.template)) {
-		ast_log(LOG_WARNING, "PP_EACH_EXTENSION requries both a macaddress and template filename.\n");
+		ast_log(LOG_WARNING, "PP_EACH_EXTENSION requires both a macaddress and template filename.\n");
 		return 0;
 	}
 
diff --git a/res/res_pjsip.c b/res/res_pjsip.c
index 2b30317..697767d 100644
--- a/res/res_pjsip.c
+++ b/res/res_pjsip.c
@@ -1052,7 +1052,7 @@
 						It can be one of the following values:
 						</para><enumlist>
 							<enum name="no"><para>
-								meaning no verificaton is done.
+								meaning no verification is done.
 							</para></enum>
 							<enum name="fingerprint"><para>
 								meaning to verify the remote fingerprint.
@@ -1565,7 +1565,7 @@
 						in their WWW-Authenticate header.  It can't be blank
 						unless you expect the server to be sending a blank
 						realm in the header.  You can't use pre-hashed
-						paswords with a wildcard auth object.
+						passwords with a wildcard auth object.
 						You can generate the hash with the following shell
 						command:
 						</para>
diff --git a/res/res_pjsip/config_global.c b/res/res_pjsip/config_global.c
index aa506ce..1d44222 100644
--- a/res/res_pjsip/config_global.c
+++ b/res/res_pjsip/config_global.c
@@ -96,7 +96,7 @@
 	unsigned int unidentified_request_count;
 	/*! The period during which unidentified requests are accumulated */
 	unsigned int unidentified_request_period;
-	/*! Interval at which expired unidentifed requests will be pruned */
+	/*! Interval at which expired unidentified requests will be pruned */
 	unsigned int unidentified_request_prune_interval;
 	struct {
 		/*! Taskprocessor high water alert trigger level */
diff --git a/res/res_pjsip/pjsip_configuration.c b/res/res_pjsip/pjsip_configuration.c
index 49a7d45..f324bbb 100644
--- a/res/res_pjsip/pjsip_configuration.c
+++ b/res/res_pjsip/pjsip_configuration.c
@@ -427,7 +427,7 @@
 			return -1;
 		}
 		if (endpoint->ident_method & method) {
-			/* We are already indentifying by this method.  No need to do it again. */
+			/* We are already identifying by this method.  No need to do it again. */
 			continue;
 		}
 
diff --git a/res/res_pjsip/pjsip_scheduler.c b/res/res_pjsip/pjsip_scheduler.c
index 0b7adc1..5210a5d 100644
--- a/res/res_pjsip/pjsip_scheduler.c
+++ b/res/res_pjsip/pjsip_scheduler.c
@@ -55,7 +55,7 @@
 	struct timeval next_periodic;
 	/*! reschedule interval in milliseconds */
 	int interval;
-	/*! ast_sched scheudler id */
+	/*! ast_sched scheduler id */
 	int current_scheduler_id;
 	/*! task is currently running */
 	int is_running;
diff --git a/res/res_pjsip/pjsip_session.c b/res/res_pjsip/pjsip_session.c
index 7dc6221..429fc6d 100644
--- a/res/res_pjsip/pjsip_session.c
+++ b/res/res_pjsip/pjsip_session.c
@@ -119,7 +119,7 @@
 	/* free the supplements */
 	while ((iter = AST_LIST_REMOVE_HEAD(&session->supplements, next))) {
 		if (iter->module) {
-			/* referenced session closed. decreasing modue reference. */
+			/* referenced session closed. decreasing module reference. */
 			ast_module_unref(iter->module);
 		}
 
diff --git a/res/res_pjsip_config_wizard.c b/res/res_pjsip_config_wizard.c
index 8611be7..4c1c59b 100644
--- a/res/res_pjsip_config_wizard.c
+++ b/res/res_pjsip_config_wizard.c
@@ -52,7 +52,7 @@
 
 /*** DOCUMENTATION
 	<configInfo name="res_pjsip_config_wizard" language="en_US">
-		<synopsis>Module that privides simple configuration wizard capabilities.</synopsis>
+		<synopsis>Module that provides simple configuration wizard capabilities.</synopsis>
 		<description><para>
 			<emphasis>PJSIP Configuration Wizard</emphasis>
 			</para>
diff --git a/res/res_pjsip_header_funcs.c b/res/res_pjsip_header_funcs.c
index 4b12079..ac3bea4 100644
--- a/res/res_pjsip_header_funcs.c
+++ b/res/res_pjsip_header_funcs.c
@@ -311,7 +311,7 @@
 			pj_hdr_string_len = pjsip_hdr_print_on(hdr, pj_hdr_string, data->len - 1);
 			if (pj_hdr_string_len == -1) {
 				ast_log(AST_LOG_ERROR,
-					"Not enought buffer space in pjsip_hdr_print_on\n");
+					"Not enough buffer space in pjsip_hdr_print_on\n");
 				return -1;
 			}
 			pj_hdr_string[pj_hdr_string_len] = '\0';
@@ -411,7 +411,7 @@
 	pj_hdr_string_len = pjsip_hdr_print_on(hdr, pj_hdr_string, data->len - 1);
 	if (pj_hdr_string_len == -1) {
 		ast_log(AST_LOG_ERROR,
-			"Not enought buffer space in pjsip_hdr_print_on\n");
+			"Not enough buffer space in pjsip_hdr_print_on\n");
 		return -1;
 	}
 
@@ -441,7 +441,7 @@
 
 /*!
  * \internal
- * \brief Implements PJSIP_HEADER 'add' by inserting the specified header into thge list.
+ * \brief Implements PJSIP_HEADER 'add' by inserting the specified header into the list.
  *
  * Retrieve the header_datastore from the session or create one if it doesn't exist.
  * Create and initialize the list if needed.
diff --git a/res/res_pjsip_messaging.c b/res/res_pjsip_messaging.c
index c69601c..571a7c9 100644
--- a/res/res_pjsip_messaging.c
+++ b/res/res_pjsip_messaging.c
@@ -513,7 +513,7 @@
 	*atsign = '\0';
 	endpoint_name = destination;
 
-	/* Apprently there may be ';<user_options>' after the endpoint name ??? */
+	/* Apparently there may be ';<user_options>' after the endpoint name ??? */
 	AST_SIP_USER_OPTIONS_TRUNCATE_CHECK(endpoint_name);
 	endpoint = ast_sorcery_retrieve_by_id(ast_sip_get_sorcery(), "endpoint", endpoint_name);
 	if (!endpoint) {
diff --git a/res/res_pjsip_nat.c b/res/res_pjsip_nat.c
index 1b5fdd1..2d5e6a7 100644
--- a/res/res_pjsip_nat.c
+++ b/res/res_pjsip_nat.c
@@ -207,7 +207,7 @@
 
 	if (endpoint->nat.rewrite_contact) {
 		/* rewrite_contact is intended to ensure we send requests/responses to
-		 * a routeable address when NAT is involved. The URI that dictates where
+		 * a routable address when NAT is involved. The URI that dictates where
 		 * we send requests/responses can be determined either by Record-Route
 		 * headers or by the Contact header if no Record-Route headers are present.
 		 * We therefore will attempt to rewrite a Record-Route header first, and if
diff --git a/res/res_pjsip_outbound_authenticator_digest.c b/res/res_pjsip_outbound_authenticator_digest.c
index 3f8732c..55781e9 100644
--- a/res/res_pjsip_outbound_authenticator_digest.c
+++ b/res/res_pjsip_outbound_authenticator_digest.c
@@ -141,7 +141,7 @@
 	 * structures. In this case however, the elements are the
 	 * structures themselves instead of pointers to them.  This is due
 	 * to the fact that pjsip_auth_clt_set_credentials() expects an
-	 * array of structues, not an array of pointers to structures.
+	 * array of structures, not an array of pointers to structures.
 	 * Thankfully, vectors allow you to "steal" their underlying
 	 * arrays, in this case an array of pjsip_cred_info structures,
 	 * which we'll pass to pjsip_auth_clt_set_credentials() at the
diff --git a/res/res_pjsip_outbound_registration.c b/res/res_pjsip_outbound_registration.c
index ad60318..2ee7cca 100644
--- a/res/res_pjsip_outbound_registration.c
+++ b/res/res_pjsip_outbound_registration.c
@@ -308,7 +308,7 @@
 		AST_STRING_FIELD(client_uri);
 		/*! \brief Optional user for contact header */
 		AST_STRING_FIELD(contact_user);
-		/*! \bried Optional header parameters for contact */
+		/*! \brief Optional header parameters for contact */
 		AST_STRING_FIELD(contact_header_params);
 		/*! \brief Explicit transport to use for registration */
 		AST_STRING_FIELD(transport);
diff --git a/res/res_pjsip_pubsub.c b/res/res_pjsip_pubsub.c
index dd08871..e62582f 100644
--- a/res/res_pjsip_pubsub.c
+++ b/res/res_pjsip_pubsub.c
@@ -481,7 +481,7 @@
 	const struct ast_sip_subscription_handler *handler;
 	/*! Pointer to the base of the tree */
 	struct sip_subscription_tree *tree;
-	/*! Body generaator for NOTIFYs */
+	/*! Body generator for NOTIFYs */
 	struct ast_sip_pubsub_body_generator *body_generator;
 	/*! Vector of child subscriptions */
 	AST_VECTOR(, struct ast_sip_subscription *) children;
diff --git a/res/res_pjsip_rfc3326.c b/res/res_pjsip_rfc3326.c
index 6a02641..7d096c1 100644
--- a/res/res_pjsip_rfc3326.c
+++ b/res/res_pjsip_rfc3326.c
@@ -100,7 +100,7 @@
 	}
 
 	if (session->endpoint && session->endpoint->suppress_q850_reason_headers) {
-		ast_debug(1, "A Q.850 '%s'(%i) Reason header was suppresed for endpoint '%s'\n",
+		ast_debug(1, "A Q.850 '%s'(%i) Reason header was suppressed for endpoint '%s'\n",
 			ast_cause2str((ast_channel_hangupcause(session->channel) & 0x7f)),
 			(ast_channel_hangupcause(session->channel) & 0x7f),
 			ast_sorcery_object_get_id(session->endpoint));
diff --git a/res/res_pjsip_session.c b/res/res_pjsip_session.c
index 4eb855a..2fb5b46 100644
--- a/res/res_pjsip_session.c
+++ b/res/res_pjsip_session.c
@@ -3098,7 +3098,7 @@
 
 	session->authentication_challenge_count = 0;
 
-	/* Fire seesion begin handlers */
+	/* Fire session begin handlers */
 	handle_session_begin(session);
 
 	/* Avoid unnecessary ref manipulation to return a session */
diff --git a/res/res_pktccops.c b/res/res_pktccops.c
index 069d0f6..6b6ad33 100644
--- a/res/res_pktccops.c
+++ b/res/res_pktccops.c
@@ -1334,7 +1334,7 @@
 	case CLI_INIT:
 		e->command = "pktccops gateset";
 		e->usage =
-			"Usage: pktccops gateset <cmts> <mta> <acctcount> <bitrate> <packet size> <switch ip> <switch port>\n"
+			"Usage: pktccops gateset <cmts> <mta> <actcount> <bitrate> <packet size> <switch ip> <switch port>\n"
 			"       Send Gate-Set to cmts.\n";
 		return NULL;
 	case CLI_GENERATE:
diff --git a/res/res_smdi.c b/res/res_smdi.c
index e34f4f3..5b448a17 100644
--- a/res/res_smdi.c
+++ b/res/res_smdi.c
@@ -1071,7 +1071,7 @@
 
 			/* get the current attributes from the port */
 			if (tcgetattr(iface->fd, &iface->mode)) {
-				ast_log(LOG_ERROR, "Error getting atributes of %s (%s)\n", iface->name, strerror(errno));
+				ast_log(LOG_ERROR, "Error getting attributes of %s (%s)\n", iface->name, strerror(errno));
 				continue;
 			}
 
diff --git a/res/res_sorcery_config.c b/res/res_sorcery_config.c
index dfe7a35..7f72b60 100644
--- a/res/res_sorcery_config.c
+++ b/res/res_sorcery_config.c
@@ -392,7 +392,7 @@
 		RAII_VAR(void *, obj, NULL, ao2_cleanup);
 		id = ast_category_get_name(category);
 
-		/* If given configurationhas not been met skip the category, it is not applicable */
+		/* If given configuration has not been met skip the category, it is not applicable */
 		if (!sorcery_is_configuration_met(sorcery, type, category, config)) {
 			continue;
 		}
diff --git a/res/res_stasis.c b/res/res_stasis.c
index f16062b..fb066ba 100644
--- a/res/res_stasis.c
+++ b/res/res_stasis.c
@@ -1203,7 +1203,7 @@
 }
 
 static const struct ast_datastore_info masquerade_store_info = {
-	.type = "stasis-masqerade",
+	.type = "stasis-masquerade",
 	.chan_fixup = channel_stolen_cb,
 	.chan_breakdown = channel_replaced_cb,
 };
diff --git a/res/res_stasis_playback.c b/res/res_stasis_playback.c
index d558e18..b948bf8 100644
--- a/res/res_stasis_playback.c
+++ b/res/res_stasis_playback.c
@@ -598,7 +598,7 @@
 	return ast_json_ref(json);
 }
 
-typedef int (*playback_opreation_cb)(struct stasis_app_playback *playback);
+typedef int (*playback_operation_cb)(struct stasis_app_playback *playback);
 
 static int playback_noop(struct stasis_app_playback *playback)
 {
@@ -695,7 +695,7 @@
  * \brief A sparse array detailing how commands should be handled in the
  * various playback states. Unset entries imply invalid operations.
  */
-playback_opreation_cb operations[STASIS_PLAYBACK_STATE_MAX][STASIS_PLAYBACK_MEDIA_OP_MAX] = {
+playback_operation_cb operations[STASIS_PLAYBACK_STATE_MAX][STASIS_PLAYBACK_MEDIA_OP_MAX] = {
 	[STASIS_PLAYBACK_STATE_QUEUED][STASIS_PLAYBACK_STOP] = playback_cancel,
 	[STASIS_PLAYBACK_STATE_QUEUED][STASIS_PLAYBACK_RESTART] = playback_noop,
 
@@ -727,7 +727,7 @@
 	struct stasis_app_playback *playback,
 	enum stasis_app_playback_media_operation operation)
 {
-	playback_opreation_cb cb;
+	playback_operation_cb cb;
 	SCOPED_AO2LOCK(lock, playback);
 
 	ast_assert((unsigned int)playback->state < STASIS_PLAYBACK_STATE_MAX);
diff --git a/res/res_stir_shaken/curl.c b/res/res_stir_shaken/curl.c
index 2030f46..e765b5d 100644
--- a/res/res_stir_shaken/curl.c
+++ b/res/res_stir_shaken/curl.c
@@ -217,7 +217,7 @@
 
 	curl = get_curl_instance(data);
 	if (!curl) {
-		ast_log(LOG_ERROR, "Failed to set up CURL isntance for '%s'\n", public_cert_url);
+		ast_log(LOG_ERROR, "Failed to set up CURL instance for '%s'\n", public_cert_url);
 		fclose(public_key_file);
 		remove(tmp_filename);
 		return NULL;
diff --git a/res/res_stir_shaken/curl.h b/res/res_stir_shaken/curl.h
index 7009d36..ae8feda 100644
--- a/res/res_stir_shaken/curl.h
+++ b/res/res_stir_shaken/curl.h
@@ -18,7 +18,7 @@
 #ifndef _STIR_SHAKEN_CURL_H
 #define _STIR_SHAKEN_CURL_H
 
-/* Forward declarion for CURL callback data */
+/* Forward declaration for CURL callback data */
 struct curl_cb_data;
 
 /*!
diff --git a/res/res_xmpp.c b/res/res_xmpp.c
index 63dc257..ebf128d 100644
--- a/res/res_xmpp.c
+++ b/res/res_xmpp.c
@@ -385,7 +385,7 @@
 				<configOption name="buddy">
 					<synopsis>Manual addition of buddy to list</synopsis>
 					<description><para>
-					Manual addition of buddy to the buddy list. For distributed events, these budies are
+					Manual addition of buddy to the buddy list. For distributed events, these buddies are
 					automatically added in the whitelist as 'owners' of the node(s).
 					</para></description>
 				</configOption>
diff --git a/res/snmp/agent.c b/res/snmp/agent.c
index 2a0eb75..1a28004 100644
--- a/res/snmp/agent.c
+++ b/res/snmp/agent.c
@@ -75,7 +75,7 @@
 #include "asterisk/ast_version.h"
 #include "asterisk/pbx.h"
 
-/* Colission between Net-SNMP and Asterisk */
+/* Collision between Net-SNMP and Asterisk */
 #define unload_module ast_unload_module
 #include "asterisk/module.h"
 #undef unload_module
diff --git a/res/stasis_recording/stored.c b/res/stasis_recording/stored.c
index 909524e..3232c6d 100644
--- a/res/stasis_recording/stored.c
+++ b/res/stasis_recording/stored.c
@@ -174,7 +174,7 @@
 /*!
  * \brief Finds a recording in the given directory.
  *
- * This function searchs for a file with the given file name, with a registered
+ * This function searches for a file with the given file name, with a registered
  * format that matches its extension.
  *
  * \param dir_name Directory to search (absolute path).

diff --git a/res/res_rtp_asterisk.c b/res/res_rtp_asterisk.c
index 7b236be..0f64a07 100644
--- a/res/res_rtp_asterisk.c
+++ b/res/res_rtp_asterisk.c
@@ -5688,7 +5688,7 @@
 						  then falls to 0 at its end)
 		+3 (+5,+7,...)  - detected DTMF digit (0..9,*,#,A-D,...)
 		Repeated DTMF information (bytes 4/5, 6/7) is history shifted right
-		by each new packet and thus provides some redudancy.
+		by each new packet and thus provides some redundancy.
 
 		Sample of Cisco RTP DTMF packet is (all data in hex):
 			19 07 00 02 12 02 20 02
@@ -5751,7 +5751,7 @@
 	struct ast_rtp *rtp = ast_rtp_instance_get_data(instance);
 
 	/* Convert comfort noise into audio with various codecs.  Unfortunately this doesn't
-	   totally help us out becuase we don't have an engine to keep it going and we are not
+	   totally help us out because we don't have an engine to keep it going and we are not
 	   guaranteed to have it every 20ms or anything */
 	if (ast_debug_rtp_packet_is_allowed) {
 		ast_debug(0, "- RTP 3389 Comfort noise event: Format %s (len = %d)\n",
@@ -8035,7 +8035,7 @@
 			ast_free(payload);
 
 			if (!frame) {
-				/* If this packet can't be interpeted due to being out of memory we return what we have and assume
+				/* If this packet can't be interpreted due to being out of memory we return what we have and assume
 				 * that we will determine it is a missing packet later and NACK for it.
 				 */
 				return AST_LIST_FIRST(&frames);
@@ -8576,7 +8576,7 @@
 }
 
 /*!
  * \brief Write t140 redundacy frame
  *
  * \param data primary data to be buffered
  *
@@ -8576,7 +8576,7 @@
 
 /*!
- * \brief Write t140 redundacy frame
+ * \brief Write t140 redundancy frame
  *
  * \param data primary data to be buffered
-- 
To view, visit https://gerrit.asterisk.org/c/asterisk/+/17312
To unsubscribe, or for help writing mail filters, visit https://gerrit.asterisk.org/settings

Gerrit-Project: asterisk
Gerrit-Branch: master
Gerrit-Change-Id: I88485116d2c59b776aa2e1f8b4ce8239a21decda
Gerrit-Change-Number: 17312
Gerrit-PatchSet: 2
Gerrit-Owner: Josh Soref <jsoref at gmail.com>
Gerrit-Reviewer: Friendly Automation
Gerrit-Reviewer: George Joseph <gjoseph at digium.com>
Gerrit-Reviewer: Joshua Colp <jcolp at sangoma.com>
Gerrit-MessageType: merged
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.digium.com/pipermail/asterisk-code-review/attachments/20211115/334e1e9c/attachment-0001.html>


More information about the asterisk-code-review mailing list